==> moodle-3.4.4.zip: moodle/lang/en/access.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'access', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core_access
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['access'] = 'Accessibility';
$string['accesshelp'] = 'Accessibility help';
$string['accesskey'] = 'Access key, {$a}';
$string['accessstatement'] = 'Accessibility statement';
$string['activitynext'] = 'Next activity';
$string['activityprev'] = 'Previous activity';
$string['breadcrumb'] = 'Breadcrumb trail';
$string['hideblocka'] = 'Hide {$a} block';
$string['showblocka'] = 'Show {$a} block';
$string['sitemap'] = 'Site map';
$string['skipa'] = 'Skip {$a}';
$string['skipblock'] = 'Skip block';
$string['skipnavigation'] = 'Skip navigation';
$string['skipto'] = 'Skip to {$a}';
$string['tocontent'] = 'Skip to main content';
$string['tonavigation'] = 'Go to navigation';
$string['youarehere'] = 'You are here';

// Deprecated since Moodle 3.4.
$string['monthnext'] = 'Next month';
$string['monthprev'] = 'Previous month';

==> moodle-3.6.10.zip: moodle/lang/en/access.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'access', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   core_access
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['access'] = 'Accessibility';
$string['accesshelp'] = 'Accessibility help';
$string['accesskey'] = 'Access key, {$a}';
$string['accessstatement'] = 'Accessibility statement';
$string['activitynext'] = 'Next activity';
$string['activityprev'] = 'Previous activity';
$string['breadcrumb'] = 'Navigation bar';
$string['eventcontextlocked'] = 'Context frozen';
$string['eventcontextunlocked'] = 'Context unfrozen';
$string['hideblocka'] = 'Hide {$a} block';
$string['showblocka'] = 'Show {$a} block';
$string['sitemap'] = 'Site map';
$string['skipa'] = 'Skip {$a}';
$string['skipblock'] = 'Skip block';
$string['skipnavigation'] = 'Skip navigation';
$string['skipto'] = 'Skip to {$a}';
$string['tocontent'] = 'Skip to main content';
$string['tonavigation'] = 'Go to navigation';
$string['youarehere'] = 'You are here';

// Deprecated since Moodle 3.4.
$string['monthnext'] = 'Next month';
$string['monthprev'] = 'Previous month';
